@@ -1,5 +1,5 @@
 package Business::AuthorizeNet::CIM;
-$Business::AuthorizeNet::CIM::VERSION = '0.12';
+$Business::AuthorizeNet::CIM::VERSION = '0.13';
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
 
@@ -22,7 +22,7 @@ sub new {
         $args->{url} = 'https://apitest.authorize.net/xml/v1/request.api';
     }
     else {
-        $args->{url} = 'https://api.authorize.net/xml/v1/request.api';
+        $args->{url} = 'https://api2.authorize.net/xml/v1/request.api';
     }
 
     unless ( $args->{ua} ) {
@@ -131,6 +131,9 @@ sub createCustomerProfile {
         if ( $self->{test_mode} ) {
             $writer->dataElement( 'validationMode', 'testMode' );
         }
+        elsif ( $args->{validationMode} ) {
+            $writer->dataElement( 'validationMode', $args->{validationMode} );
+        }
         else {
             $writer->dataElement( 'validationMode', 'liveMode' );
         }
@@ -209,6 +212,9 @@ sub createCustomerPaymentProfileRequest {
     if ( $self->{test_mode} ) {
         $writer->dataElement( 'validationMode', 'testMode' );
     }
+    elsif ( $args->{validationMode} ) {
+        $writer->dataElement( 'validationMode', $args->{validationMode} );
+    }
     else {
         $writer->dataElement( 'validationMode', 'liveMode' );
     }
@@ -700,6 +706,9 @@ sub updateCustomerPaymentProfile {
     if ( $self->{test_mode} ) {
         $writer->dataElement( 'validationMode', 'testMode' );
     }
+    elsif ( $args->{validationMode} ) {
+        $writer->dataElement( 'validationMode', $args->{validationMode} );
+    }
     else {
         $writer->dataElement( 'validationMode', 'liveMode' );
     }
@@ -835,7 +844,7 @@ Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) W
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
